@@ -38,7 +38,7 @@ use super::network::{
     NewSubnet, Port, PortQuery, Subnet, SubnetQuery,
 };
 #[cfg(feature = "object-storage")]
-use super::object_storage::{Container, ContainerQuery, Object, ObjectQuery};
+use super::object_storage::{Container, ContainerQuery, NewObject, Object, ObjectQuery};
 use super::Result;
 
 /// OpenStack cloud API.
@@ -66,8 +66,6 @@ impl Cloud {
     ///         .with_project_scope("project1", "Default");
     ///     Ok(openstack::Cloud::new(auth))
     /// }
-    ///
-    /// # fn main() { cloud().unwrap(); }
     /// ```
     ///
     /// # See Also
@@ -88,7 +86,6 @@ impl Cloud {
     /// # fn cloud_from_config() -> openstack::Result<()> {
     /// let os = openstack::Cloud::from_config("cloud-1")?;
     /// # Ok(()) }
-    /// # fn main() { cloud_from_config().unwrap(); }
     /// ```
     pub fn from_config<S: AsRef<str>>(cloud_name: S) -> Result<Cloud> {
         Ok(Cloud {
@@ -104,7 +101,6 @@ impl Cloud {
     /// # fn cloud_from_env() -> openstack::Result<()> {
     /// let os = openstack::Cloud::from_env()?;
     /// # Ok(()) }
-    /// # fn main() { cloud_from_env().unwrap(); }
     /// ```
     pub fn from_env() -> Result<Cloud> {
         Ok(Cloud {
@@ -121,8 +117,6 @@ impl Cloud {
     ///     openstack::Cloud::from_env()
     ///         .map(|os| os.with_endpoint_interface("internal"))
     /// }
-    ///
-    /// # fn main() { cloud_from_env().unwrap(); }
     /// ```
     pub fn with_endpoint_interface<S>(mut self, endpoint_interface: S) -> Cloud
     where
@@ -611,6 +605,20 @@ impl Cloud {
         self.find_subnets().all()
     }
 
+    /// Prepare a new object for creation.
+    ///
+    /// This call returns a `NewObject` object, which is a builder
+    /// to create object in object storage.
+    #[cfg(feature = "object-storage")]
+    pub fn new_object<C, O, B>(&self, container: C, object: O, body: B) -> NewObject<B>
+    where
+        C: Into<ContainerRef>,
+        O: Into<String>,
+        B: io::Read + Send + 'static,
+    {
+        NewObject::new(self.session.clone(), container.into(), object.into(), body)
+    }
+
     /// Prepare a new floating IP for creation.
     ///
     /// This call returns a `NewFloatingIp` object, which is a builder
