@@ -24,7 +24,7 @@ pub use osauth::ApiVersion;
 pub use self::resourceiterator::{ResourceIterator, ResourceQuery};
 pub(crate) use self::types::IntoVerified;
 pub use self::types::{
-    FlavorRef, ImageRef, KeyPairRef, NetworkRef, PortRef, ProjectRef, Refresh, RouterRef,
-    SnapshotRef, SubnetRef, UserRef, VolumeRef,
+    ContainerRef, FlavorRef, ImageRef, KeyPairRef, NetworkRef, ObjectRef, PortRef, ProjectRef,
+    Refresh, RouterRef, SecurityGroupRef, SnapshotRef, SubnetRef, UserRef, VolumeRef,
 };
 pub use self::waiter::DeletionWaiter;
