@@ -173,6 +173,7 @@ where
     }
 }
 
+#[allow(clippy::trivially_copy_pass_by_ref)]
 fn config_drive_string_to_bool<S>(has_config_drive: &Option<bool>, s: S) -> Result<S::Ok, S::Error>
 where
     S: Serializer,
@@ -206,6 +207,8 @@ pub struct Server {
     pub id: String,
     #[serde(deserialize_with = "empty_as_default", default)]
     pub image: Option<Ref>,
+    #[serde(rename = "OS-EXT-SRV-ATTR:instance_name", default)]
+    pub instance_name: Option<String>,
     #[serde(rename = "key_name", deserialize_with = "empty_as_default", default)]
     pub key_pair_name: Option<String>,
     pub name: String,
