@@ -112,7 +112,6 @@
     const_err,
     dead_code,
     improper_ctypes,
-    legacy_directory_ownership,
     missing_copy_implementations,
     missing_debug_implementations,
     missing_docs,
@@ -121,13 +120,10 @@
     overflowing_literals,
     path_statements,
     patterns_in_fns_without_body,
-    plugin_as_library,
     private_in_public,
-    safe_extern_statics,
     trivial_casts,
     trivial_numeric_casts,
     unconditional_recursion,
-    unions_with_drop_fields,
     unsafe_code,
     unused,
     unused_allocation,
