@@ -388,6 +388,12 @@ impl NewNetwork {
             -> port_security_enabled: optional bool
     }
 
+    creation_inner_field! {
+        #[doc = "Configure whether the network is shared across all projects."]
+        set_shared, with_shared
+            -> shared: bool
+    }
+
     creation_inner_field! {
         #[doc = "Configure VLAN transparency mode of the network."]
         set_vlan_transparent, with_vlan_transparent
