@@ -19,13 +19,13 @@ extern crate waiter;
 use std::env;
 use std::fs::File;
 use std::io::Read;
-use std::sync::{Once, ONCE_INIT};
+use std::sync::Once;
 
 use waiter::Waiter;
 
 use openstack::Refresh;
 
-static INIT: Once = ONCE_INIT;
+static INIT: Once = Once::new();
 
 fn set_up() -> openstack::Cloud {
     INIT.call_once(|| {
